@@ -98,6 +98,39 @@
  "latin-3-prefix" "Latin-3" 'quail-use-package
  "3>" "Latin-3 characters input method with prefix modifiers"
  "quail/latin-pre")
+(register-input-method
+ "polish-slash" "Polish" 'quail-use-package
+ "PL>" "Polish diacritics and slash character are input as `/[acelnosxzACELNOSXZ/]'."
+ "quail/latin-pre")
+(register-input-method
+ "latin-9-prefix" "Latin-9" 'quail-use-package
+ "0>" "Latin-9 characters input method with prefix modifiers"
+ "quail/latin-pre")
+(register-input-method
+ "latin-8-prefix" "Latin-8" 'quail-use-package
+ "8>" "Latin-8 characters input method with prefix modifiers"
+ "quail/latin-pre")
+(register-input-method
+ "latin-prefix" "Latin" 'quail-use-package
+ "L>" "Latin characters input method with prefix modifiers."
+ "quail/latin-pre")
+(register-input-method
+ "latin-10-prefix" "Latin-10" 'quail-use-package
+ "10>" "Latin-10 characters input method with prefix modifiers"
+ "quail/latin-pre")
+(register-input-method
+ "latin-7-prefix" "Latin-7" 'quail-use-package
+ "7>" "Latin-7 characters input method with prefix modifiers"
+ "quail/latin-pre")
+(register-input-method
+ "latin-5-prefix" "Latin-5" 'quail-use-package
+ "5>" "Latin-5 characters input method with prefix modifiers"
+ "quail/latin-pre")
+(register-input-method
+ "latin-4-prefix" "Latin-4" 'quail-use-package
+ "4>" "Latin-4 characters input method with prefix modifiers"
+ "quail/latin-pre")
+
 (register-input-method
  "latin-1-postfix" "Latin-1" 'quail-use-package
  "1<" "Latin-1 character input method with postfix modifiers"
@@ -162,6 +195,46 @@
  "swedish-postfix" "Latin-1" 'quail-use-package
  "SV<" "Swedish (Svenska) input method (rule: AA -> ,AE(B, AE -> ,AD(B, OE -> ,AV(B, E' -> ,AI(B)"
  "quail/latin-post")
+(register-input-method
+ "czech" "Czech" 'quail-use-package
+ "CZ" "\"Standard\" Czech keyboard in the Windoze NT 105 keys version."
+ "quail/czech")
+(register-input-method
+ "czech-qwerty" "Czech" 'quail-use-package
+ "CZ" "\"Standard\" Czech keyboard in the Windoze NT 105 keys version, QWERTY layout."
+ "quail/czech")
+(register-input-method
+ "czech-prog-1" "Czech" 'quail-use-package
+ "CZ" "Czech (non-standard) keyboard for programmers #1.
+
+All digits except of `1' are replaced by Czech characters as on the standard
+Czech keyboard.
+`1' is replaced by `+'.
+`+' is a dead key.  Multiple presses of the dead key generate various accents.
+All other keys are the same as on standard US keyboard."
+ "quail/czech")
+(register-input-method
+ "czech-prog-2" "Czech" 'quail-use-package
+ "CZ" "Czech (non-standard) keyboard for programmers #2.
+
+All digits except of `1' are replaced by Czech characters as on the standard
+Czech keyboard.
+`1' is replaced by `,By(B'.
+`+' is a dead key.  Multiple presses of the dead key generate various accents.
+All other keys are the same as on standard US keyboard."
+ "quail/czech")
+(register-input-method
+ "czech-prog-3" "Czech" 'quail-use-package
+ "CZ" "Czech (non-standard) keyboard for programmers compatible with the
+default keyboard from the obsolete `emacs-czech' package.
+
+All digits except of `1' are replaced by Czech characters as on the standard
+Czech keyboard.
+`[' and `]' are replaced with `,Bz(B' and `,By(B', respectively.
+There are two dead keys on `=' and `+'.  Characters with diaresis are
+accessible through `+='.
+All other keys are the same as on standard US keyboard."
+ "quail/czech")
 (register-input-method
  "turkish-postfix" "Latin-3" 'quail-use-package
  "TR<" "Turkish (T,C|(Brk,Cg(Be) input method with postfix modifiers"
@@ -195,8 +268,8 @@
  "SV@" "Swedish (Svenska) input method simulating SUN Swedish/Finnish keyboard"
  "quail/latin-post")
 (register-input-method
- "finish-keyboard" "Latin-1" 'quail-use-package
- "FI@" "Finish input method simulating SUN Finnish/Swedish keyboard"
+ "finnish-keyboard" "Latin-1" 'quail-use-package
+ "FI@" "Finnish input method simulating SUN Finnish/Swedish keyboard"
  "quail/latin-post")
 (register-input-method
  "german" "Latin-1" 'quail-use-package
@@ -238,6 +311,10 @@
  "danish-alt-postfix" "Latin-1" 'quail-use-package
  "DA<" "Danish input method (rule: AE -> ,AF(B, OE -> ,AX(B, AA -> ,AE(B, E' -> ,AI(B)"
  "quail/latin-alt")
+(register-input-method
+ "lao" "Lao" 'quail-use-package
+ "(1E(B" "Lao input method simulating Lao keyboard layout based on Thai TIS620"
+ "quail/lao")
 (register-input-method
  "esperanto-alt-postfix" "Latin-3" 'quail-use-package
  "EO<" "Esperanto input method with postfix modifiers"
@@ -282,10 +359,31 @@
  "turkish-alt-postfix" "Latin-3" 'quail-use-package
  "TR<" "Turkish (T,C|(Brk,Cg(Be) input method with postfix modifiers"
  "quail/latin-alt")
-(register-input-method
- "ipa" "IPA" 'quail-use-package
- "IPA" "International Phonetic Alphabet for English, French, German and Italian"
- "quail/ipa")
+
+(if (not (and (fboundp 'decode-char) (decode-char 'ucs #x31C)
+              (eq #x31C (encode-char (decode-char 'ucs #x31C) 'ucs))))
+    (register-input-method
+     "ipa" "IPA" 'quail-use-package
+     "IPA"
+     "International Phonetic Alphabet for English, French, German and Italian"
+     "quail/ipa")
+
+  (register-input-method
+   "kirshenbaum-ipa" "IPA" 'quail-use-package
+   "IPA-K"
+   "International Phonetic Alphabet, Kirshenbaum ASCII transliteration."
+   "quail/ipa-21.5")
+  (register-input-method
+   "x-sampa-ipa" "IPA" 'quail-use-package
+   "IPA-S"
+   "International Phonetic Alphabet, X-SAMPA ASCII transliteration."
+   "quail/ipa-21.5")
+  (register-input-method
+   "ipa" "IPA" 'quail-use-package
+   "IPA"
+   "International Phonetic Alphabet for English, French, German and Italian"
+   "quail/ipa-21.5"))
+
 (register-input-method
  "korean-hanja" "Korean" 'quail-use-package
  "$(C9zyS(B" "2$(C9z=D(BKSC$(CySm.(B: $(Cz1SWGO4B(B $(CySm.@G(B $(Cj$@;(B $(CGQ1[(B2$(C9zcR@87N(B $(C{<usGO?)(B $(C`TwI(B"
@@ -358,6 +456,14 @@
  "chinese-tonepy" "Chinese-GB" 'quail-use-package
  "$A5wF4(B" "$A::WVJdHk!K4x5wF4Rt!K!!(B"
  "quail/TONEPY")
+(register-input-method
+ "tibetan-wylie" "Tibetan" 'quail-use-package
+ "TIBw" "Tibetan character input by Extended Wylie key assignment."
+ "quail/tibetan")
+(register-input-method
+ "tibetan-tibkey" "Tibetan" 'quail-use-package
+ "TIBt" "Tibetan character input by TibKey key assignment."
+ "quail/tibetan")
 (register-input-method
  "chinese-sw" "Chinese-GB" 'quail-use-package
  "$AJWN2(B" "$A::WVJdHk!KJWN2!K!!(B"
@@ -414,3 +520,7 @@
  "chinese-4corner" "Chinese-BIG5" 'quail-use-package
  "$(0(?-F(B" "$(0(?-FHAP#(B:: "
  "quail/4Corner")
+(register-input-method
+ "croatian" "Croatian" 'quail-use-package
+ "HR" "\"Standard\" Croatian keyboard."
+ "quail/croatian")
